# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google_internal_apis/dummy.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n google_internal_apis/dummy.proto\x1a\x1egoogle/protobuf/wrappers.proto\"A\n\x0c\x44ummyMessage\x12\x31\n\x0b\x64ummy_field\x18\x01 \x01(\x0b\x32\x1c.google.protobuf.StringValue')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'google_internal_apis.dummy_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_DUMMYMESSAGE']._serialized_start=68
  _globals['_DUMMYMESSAGE']._serialized_end=133
# @@protoc_insertion_point(module_scope)
